import 'dart:ui';

import 'package:elevarm_icons/elevarm_icons.dart';
import 'package:elevarm_ui/elevarm_ui.dart';
import 'package:elevarm_ui/src/styles/styles.dart';
import 'package:flutter/material.dart';

class ElevarmConfirmAlertDialog {
  /// Dialog's title
  final String title;

  /// Dialog's subtitle
  final String subtitle;

  /// Positive button text
  final String positiveText;

  /// Negative button text
  final String negativeText;

  /// Callback on positive button
  final VoidCallback onPositiveButton;

  /// Callback on negative button
  final VoidCallback onNegativeButton;

  /// Dialog's variant.
  final ElevarmDialogVariant variant;

  // Dialog's icon asset name.
  final String? iconAssetName;

  const ElevarmConfirmAlertDialog({
    required this.title,
    required this.subtitle,
    required this.onPositiveButton,
    required this.onNegativeButton,
    required this.positiveText,
    required this.negativeText,
    this.variant = ElevarmDialogVariant.basic,
    this.iconAssetName,
  });

  Future<void> show(BuildContext context) {
    String finalIconAssetName;
    Color iconColor;
    Color borderColor;
    Color backgroundColor;
    bool isPositiveButtonDestructive;
    switch (variant) {
      case ElevarmDialogVariant.danger:
        finalIconAssetName = iconAssetName ?? ElevarmIconsOutline.alertTriangle;
        iconColor = ElevarmColors.danger;
        borderColor = ElevarmColors.danger50;
        backgroundColor = ElevarmColors.danger100;
        isPositiveButtonDestructive = true;
        break;
      case ElevarmDialogVariant.basic:
      default:
        finalIconAssetName = iconAssetName ?? ElevarmIconsOutline.infoCircle;
        iconColor = ElevarmColors.neutral300;
        borderColor = ElevarmColors.neutral50;
        backgroundColor = ElevarmColors.neutral100;
        isPositiveButtonDestructive = false;
        break;
    }

    return showDialog(
      context: context,
      barrierColor: const Color.fromRGBO(16, 24, 40, 0.35),
      builder: (context) {
        return BackdropFilter(
          filter: ImageFilter.blur(sigmaX: 4.0, sigmaY: 4.0),
          child: Dialog(
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(12),
            ),
            child: Container(
              padding: const EdgeInsets.symmetric(
                horizontal: 16,
                vertical: 24,
              ),
              child: Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Center(
                    child: Container(
                      height: 56,
                      width: 56,
                      decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: backgroundColor,
                        border: Border.all(
                          width: 8,
                          color: borderColor,
                        ),
                      ),
                      child: ElevarmIcon(
                        finalIconAssetName,
                        color: iconColor,
                      ),
                    ),
                  ),
                  const SizedBox(height: 16),
                  Text(
                    title,
                    style: LibraryTextStyles.poppinsLgSemiboldNeutral,
                  ),
                  Text(
                    subtitle,
                    style: LibraryTextStyles.interSmRegularNeutral300,
                  ),
                  const SizedBox(height: 16),
                  SizedBox(
                    width: double.infinity,
                    child: ElevarmPrimaryButton.text(
                      text: positiveText,
                      onPressed: onPositiveButton,
                      isDestructive: isPositiveButtonDestructive,
                    ),
                  ),
                  const SizedBox(height: 8),
                  SizedBox(
                    width: double.infinity,
                    child: ElevarmOutlineButton.text(
                      text: negativeText,
                      onPressed: onNegativeButton,
                    ),
                  )
                ],
              ),
            ),
          ),
        );
      },
    );
  }
}
